==> net.java.html.lib-0.2-sources.jar: net/java/html/lib/Math.java <==
package net.java.html.lib;
public class Math extends net.java.html.lib.Objs {
  protected Math(net.java.html.lib.Objs.Constructor<?> c, java.lang.Object js) {
    super(c, js);
  }
  private static final class $Constructor extends net.java.html.lib.Objs.Constructor<Math> {
    $Constructor() {
      super(Math.class);
    }
    @Override
    public Math create(java.lang.Object obj) {
      return obj == null ? null : new Math(this, obj);
    }
  };
  private static final $Constructor $AS = new $Constructor();
  public static Math $as(java.lang.Object obj) {
    return $AS.create(obj);
  }
  /** The mathematical constant e. This is Euler's number, the base of natural logarithms. */
  public static double E = (double)$Typings$.readStaticFields$671();
  /** The natural logarithm of 10. */
  public static double LN10 = (double)$Typings$.readStaticFields$672();
  /** The natural logarithm of 2. */
  public static double LN2 = (double)$Typings$.readStaticFields$673();
  /** The base-2 logarithm of e. */
  public static double LOG2E = (double)$Typings$.readStaticFields$674();
  /** The base-10 logarithm of e. */
  public static double LOG10E = (double)$Typings$.readStaticFields$675();
  /** Pi. This is the ratio of the circumference of a circle to its diameter. */
  public static double PI = (double)$Typings$.readStaticFields$676();
  /** The square root of 0.5, or, equivalently, one divided by the square root of 2. */
  public static double SQRT1_2 = (double)$Typings$.readStaticFields$677();
  /** The square root of 2. */
  public static double SQRT2 = (double)$Typings$.readStaticFields$678();
  /**
  * Returns the absolute value of a number (the value without regard to whether it is positive or negative).
  * For example, the absolute value of -5 is the same as the absolute value of 5.
  * @param x A numeric expression for which the absolute value is needed.
  */
  public static double abs(double x) {
    return $Typings$.abs$679(x);
  }
  /**
  * Returns the arc cosine (or inverse cosine) of a number.
  * @param x A numeric expression.
  */
  public static double acos(double x) {
    return $Typings$.acos$680(x);
  }
  /**
  * Returns the arcsine of a number.
  * @param x A numeric expression.
  */
  public static double asin(double x) {
    return $Typings$.asin$681(x);
  }
  /**
  * Returns the arctangent of a number.
  * @param x A numeric expression for which the arctangent is needed.
  */
  public static double atan(double x) {
    return $Typings$.atan$682(x);
  }
  /**
  * Returns the angle (in radians) from the X axis to a point.
  * @param y A numeric expression representing the cartesian y-coordinate.
  * @param x A numeric expression representing the cartesian x-coordinate.
  */
  public static double atan2(double y, double x) {
    return $Typings$.atan2$683(y, x);
  }
  /**
  * Returns the smallest number greater than or equal to its numeric argument.
  * @param x A numeric expression.
  */
  public static double ceil(double x) {
    return $Typings$.ceil$684(x);
  }
  /**
  * Returns the cosine of a number.
  * @param x A numeric expression that contains an angle measured in radians.
  */
  public static double cos(double x) {
    return $Typings$.cos$685(x);
  }
  /**
  * Returns e (the base of natural logarithms) raised to a power.
  * @param x A numeric expression representing the power of e.
  */
  public static double exp(double x) {
    return $Typings$.exp$686(x);
  }
  /**
  * Returns the greatest number less than or equal to its numeric argument.
  * @param x A numeric expression.
  */
  public static double floor(double x) {
    return $Typings$.floor$687(x);
  }
  /**
  * Returns the natural logarithm (base e) of a number.
  * @param x A numeric expression.
  */
  public static double log(double x) {
    return $Typings$.log$688(x);
  }
  /**
  * Returns the larger of a set of supplied numeric expressions.
  * @param values Numeric expressions to be evaluated.
  */
  public static double max(double... values) {
    return $Typings$.max$689(values);
  }
  /**
  * Returns the smaller of a set of supplied numeric expressions.
  * @param values Numeric expressions to be evaluated.
  */
  public static double min(double... values) {
    return $Typings$.min$690(values);
  }
  /**
  * Returns the value of a base expression taken to a specified power.
  * @param x The base value of the expression.
  * @param y The exponent value of the expression.
  */
  public static double pow(double x, double y) {
    return $Typings$.pow$691(x, y);
  }
  /** Returns a pseudorandom number between 0 and 1. */
  public static double random() {
    return $Typings$.random$692();
  }
  /**
  * Returns a supplied numeric expression rounded to the nearest number.
  * @param x The value to be rounded to the nearest number.
  */
  public static double round(double x) {
    return $Typings$.round$693(x);
  }
  /**
  * Returns the sine of a number.
  * @param x A numeric expression that contains an angle measured in radians.
  */
  public static double sin(double x) {
    return $Typings$.sin$694(x);
  }
  /**
  * Returns the square root of a number.
  * @param x A numeric expression.
  */
  public static double sqrt(double x) {
    return $Typings$.sqrt$695(x);
  }
  /**
  * Returns the tangent of a number.
  * @param x A numeric expression that contains an angle measured in radians.
  */
  public static double tan(double x) {
    return $Typings$.tan$696(x);
  }
}

==> net.java.html.lib-0.3-sources.jar: net/java/html/lib/Math.java <==
package net.java.html.lib;
public class Math extends net.java.html.lib.Objs {
  protected Math(net.java.html.lib.Objs.Constructor<?> c, java.lang.Object js) {
    super(c, js);
  }
  private static final class $Constructor extends net.java.html.lib.Objs.Constructor<Math> {
    $Constructor() {
      super(Math.class);
    }
    @Override
    public Math create(java.lang.Object obj) {
      return obj == null ? null : new Math(this, obj);
    }
  };
  private static final $Constructor $AS = new $Constructor();
  public static Math $as(java.lang.Object obj) {
    return $AS.create(obj);
  }
  /** The mathematical constant e. This is Euler's number, the base of natural logarithms. */
  public static double E = (double)$Typings$.readStaticFields$671();
  /** The natural logarithm of 10. */
  public static double LN10 = (double)$Typings$.readStaticFields$672();
  /** The natural logarithm of 2. */
  public static double LN2 = (double)$Typings$.readStaticFields$673();
  /** The base-2 logarithm of e. */
  public static double LOG2E = (double)$Typings$.readStaticFields$674();
  /** The base-10 logarithm of e. */
  public static double LOG10E = (double)$Typings$.readStaticFields$675();
  /** Pi. This is the ratio of the circumference of a circle to its diameter. */
  public static double PI = (double)$Typings$.readStaticFields$676();
  /** The square root of 0.5, or, equivalently, one divided by the square root of 2. */
  public static double SQRT1_2 = (double)$Typings$.readStaticFields$677();
  /** The square root of 2. */
  public static double SQRT2 = (double)$Typings$.readStaticFields$678();
  /**
  * Returns the absolute value of a number (the value without regard to whether it is positive or negative).
  * For example, the absolute value of -5 is the same as the absolute value of 5.
  * @param x A numeric expression for which the absolute value is needed.
  */
  public static double abs(double x) {
    return $Typings$.abs$679(x);
  }
  /**
  * Returns the arc cosine (or inverse cosine) of a number.
  * @param x A numeric expression.
  */
  public static double acos(double x) {
    return $Typings$.acos$680(x);
  }
  /**
  * Returns the arcsine of a number.
  * @param x A numeric expression.
  */
  public static double asin(double x) {
    return $Typings$.asin$681(x);
  }
  /**
  * Returns the arctangent of a number.
  * @param x A numeric expression for which the arctangent is needed.
  */
  public static double atan(double x) {
    return $Typings$.atan$682(x);
  }
  /**
  * Returns the angle (in radians) from the X axis to a point.
  * @param y A numeric expression representing the cartesian y-coordinate.
  * @param x A numeric expression representing the cartesian x-coordinate.
  */
  public static double atan2(double y, double x) {
    return $Typings$.atan2$683(y, x);
  }
  /**
  * Returns the smallest number greater than or equal to its numeric argument.
  * @param x A numeric expression.
  */
  public static double ceil(double x) {
    return $Typings$.ceil$684(x);
  }
  /**
  * Returns the cosine of a number.
  * @param x A numeric expression that contains an angle measured in radians.
  */
  public static double cos(double x) {
    return $Typings$.cos$685(x);
  }
  /**
  * Returns e (the base of natural logarithms) raised to a power.
  * @param x A numeric expression representing the power of e.
  */
  public static double exp(double x) {
    return $Typings$.exp$686(x);
  }
  /**
  * Returns the greatest number less than or equal to its numeric argument.
  * @param x A numeric expression.
  */
  public static double floor(double x) {
    return $Typings$.floor$687(x);
  }
  /**
  * Returns the natural logarithm (base e) of a number.
  * @param x A numeric expression.
  */
  public static double log(double x) {
    return $Typings$.log$688(x);
  }
  /**
  * Returns the larger of a set of supplied numeric expressions.
  * @param values Numeric expressions to be evaluated.
  */
  public static double max(double... values) {
    return $Typings$.max$689(/* ArrayType*/$js(values));
  }
  /**
  * Returns the smaller of a set of supplied numeric expressions.
  * @param values Numeric expressions to be evaluated.
  */
  public static double min(double... values) {
    return $Typings$.min$690(/* ArrayType*/$js(values));
  }
  /**
  * Returns the value of a base expression taken to a specified power.
  * @param x The base value of the expression.
  * @param y The exponent value of the expression.
  */
  public static double pow(double x, double y) {
    return $Typings$.pow$691(x, y);
  }
  /** Returns a pseudorandom number between 0 and 1. */
  public static double random() {
    return $Typings$.random$692();
  }
  /**
  * Returns a supplied numeric expression rounded to the nearest number.
  * @param x The value to be rounded to the nearest number.
  */
  public static double round(double x) {
    return $Typings$.round$693(x);
  }
  /**
  * Returns the sine of a number.
  * @param x A numeric expression that contains an angle measured in radians.
  */
  public static double sin(double x) {
    return $Typings$.sin$694(x);
  }
  /**
  * Returns the square root of a number.
  * @param x A numeric expression.
  */
  public static double sqrt(double x) {
    return $Typings$.sqrt$695(x);
  }
  /**
  * Returns the tangent of a number.
  * @param x A numeric expression that contains an angle measured in radians.
  */
  public static double tan(double x) {
    return $Typings$.tan$696(x);
  }
}
